scipy.stats.levene — STAC Release Candidate documentation

### Navigation

- index
- STAC Release Candidate documentation »

# scipy.stats.levene

`scipy.stats.` `levene`(*args, **kwds)

  Perform Levene test for equal variances.

  The Levene test tests the null hypothesis that all input samples are from populations with equal variances. Levene’s test is an alternative to Bartlett’s test bartlett in the case where there are significant deviations from normality.

  Parameters: | sample1, sample2, ... : array_like The sample data, possibly with different lengths center : {‘mean’, ‘median’, ‘trimmed’}, optional Which function of the data to use in the test. The default is ‘median’. proportiontocut : float, optional When center is ‘trimmed’, this gives the proportion of data points to cut from each end. (See scipy.stats.trim_mean.) Default is 0.05.
  Returns: | W : float The test statistic. p-value : float The p-value for the test.

  Notes

  Three variations of Levene’s test are possible. The possibilities and their recommended usages are:

  > - ‘median’ : Recommended for skewed (non-normal) distributions>
  > - ‘mean’ : Recommended for symmetric, moderate-tailed distributions.
  > - ‘trimmed’ : Recommended for heavy-tailed distributions.

  References

  [R10] | http://www.itl.nist.gov/div898/handbook/eda/section3/eda35a.htm

  [R11] | Levene, H. (1960). In Contributions to Probability and Statistics: Essays in Honor of Harold Hotelling, I. Olkin et al. eds., Stanford University Press, pp. 278-292.

  [R12] | Brown, M. B. and Forsythe, A. B. (1974), Journal of the American Statistical Association, 69, 364-367

### Navigation

- index
- STAC Release Candidate documentation »